diff -ru postgresql-head/doc/src/sgml/func.sgml postgresql/doc/src/sgml/func.sgml
--- postgresql-head/doc/src/sgml/func.sgml	2012-04-03 10:44:43.979702643 +0200
+++ postgresql/doc/src/sgml/func.sgml	2012-04-03 11:21:15.075701574 +0200
@@ -14467,6 +14467,9 @@
     <primary>pg_stop_backup</primary>
    </indexterm>
    <indexterm>
+    <primary>pg_backup_start_time</primary>
+   </indexterm>
+   <indexterm>
     <primary>pg_switch_xlog</primary>
    </indexterm>
    <indexterm>
@@ -14532,6 +14535,13 @@
       </row>
       <row>
        <entry>
+        <literal><function>pg_backup_start_time()</function></literal>
+        </entry>
+       <entry><type>timestamp with time zone</type></entry>
+       <entry>Get start time of an online exclusive backup in progress.</entry>
+      </row>
+      <row>
+       <entry>
         <literal><function>pg_switch_xlog()</function></literal>
         </entry>
        <entry><type>text</type></entry>
diff -ru postgresql-head/src/backend/access/transam/xlogfuncs.c postgresql/src/backend/access/transam/xlogfuncs.c
--- postgresql-head/src/backend/access/transam/xlogfuncs.c	2012-04-03 10:44:44.227702645 +0200
+++ postgresql/src/backend/access/transam/xlogfuncs.c	2012-04-03 11:21:15.075701574 +0200
@@ -29,6 +29,7 @@
 #include "utils/numeric.h"
 #include "utils/guc.h"
 #include "utils/timestamp.h"
+#include "storage/fd.h"
 
 
 static void validate_xlog_location(char *str);
@@ -563,3 +564,67 @@
 
 	PG_RETURN_NUMERIC(result);
 }
+
+/*
+ * Returns start time of an online exclusive backup.
+ *
+ * When there's no exclusive backup in progress, the function
+ * returns NULL.
+ */
+Datum
+pg_backup_start_time(PG_FUNCTION_ARGS)
+{
+	TimestampTz                xtime;
+	FILE                        *lfp;
+	char            fline[MAXPGPATH];
+	char       backup_start_time[30];
+
+	/*
+	* See if label file is present
+	*/
+	lfp = AllocateFile(BACKUP_LABEL_FILE, "r");
+	if (lfp == NULL)
+	{
+	       if (errno != ENOENT)
+		       ereport(ERROR,
+				(errcode_for_file_access(),
+				errmsg("could not read file \"%s\": %m",
+					BACKUP_LABEL_FILE)));
+	       PG_RETURN_NULL();
+	}
+
+	/*
+	 * Parse the file to find the the START TIME line.
+	 */
+	backup_start_time[0] = '\0';
+	while (fgets(fline, sizeof(fline), lfp) != NULL)
+	{
+	       if (sscanf(fline, "START TIME: %25[^\n]\n",
+						backup_start_time) == 1)
+			break;
+	}
+
+	/*
+	* Close the backup label file.
+	*/
+	if (ferror(lfp) || FreeFile(lfp)) {
+		ereport(ERROR,
+			(errcode_for_file_access(),
+			errmsg("could not read file \"%s\": %m",
+							BACKUP_LABEL_FILE)));
+	}
+	
+	if (strlen(backup_start_time) == 0) {
+		ereport(ERROR,
+			(errcode(ERRCODE_OBJECT_NOT_IN_PREREQUISITE_STATE),
+			errmsg("invalid data in file \"%s\"",
+							BACKUP_LABEL_FILE)));
+	}
+
+	/*
+	* Convert the time string read from file to TimestampTz form.
+	*/
+	xtime = DatumGetTimestampTz(
+		DirectFunctionCall3(timestamptz_in,
+			CStringGetDatum(backup_start_time),
+			ObjectIdGetDatum(InvalidOid),Int32GetDatum(-1))
+	);
+
+	PG_RETURN_TIMESTAMPTZ(xtime);
+}
+
diff -ru postgresql-head/src/include/access/xlog_internal.h postgresql/src/include/access/xlog_internal.h
--- postgresql-head/src/include/access/xlog_internal.h	2012-04-03 10:44:45.051702642 +0200
+++ postgresql/src/include/access/xlog_internal.h	2012-04-03 11:21:15.075701574 +0200
@@ -282,5 +282,6 @@
 extern Datum pg_xlog_replay_resume(PG_FUNCTION_ARGS);
 extern Datum pg_is_xlog_replay_paused(PG_FUNCTION_ARGS);
 extern Datum pg_xlog_location_diff(PG_FUNCTION_ARGS);
+extern Datum pg_backup_start_time(PG_FUNCTION_ARGS);
 
 #endif   /* XLOG_INTERNAL_H */
diff -ru postgresql-head/src/include/catalog/pg_proc.h postgresql/src/include/catalog/pg_proc.h
--- postgresql-head/src/include/catalog/pg_proc.h	2012-04-03 10:44:45.051702642 +0200
+++ postgresql/src/include/catalog/pg_proc.h	2012-04-03 11:21:15.075701574 +0200
@@ -2924,6 +2924,8 @@
 DESCR("prepare for taking an online backup");
 DATA(insert OID = 2173 ( pg_stop_backup			PGNSP PGUID 12 1 0 0 0 f f f f t f v 0 0 25 "" _null_ _null_ _null_ _null_ pg_stop_backup _null_ _null_ _null_ ));
 DESCR("finish taking an online backup");
+DATA(insert OID = 3883 ( pg_backup_start_time		PGNSP PGUID 12 1 0 0 0 f f f f t f s 0 0 1184 "" _null_ _null_ _null_ _null_ pg_backup_start_time _null_ _null_ _null_ ));
+DESCR("start time of an online backup");
 DATA(insert OID = 2848 ( pg_switch_xlog			PGNSP PGUID 12 1 0 0 0 f f f f t f v 0 0 25 "" _null_ _null_ _null_ _null_ pg_switch_xlog _null_ _null_ _null_ ));
 DESCR("switch to new xlog file");
 DATA(insert OID = 3098 ( pg_create_restore_point	PGNSP PGUID 12 1 0 0 0 f f f f t f v 1 0 25 "25" _null_ _null_ _null_ _null_ pg_create_restore_point _null_ _null_ _null_ ));
